@@ -1,7 +1,7 @@
 // XGParamSysex.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -39,7 +39,7 @@ XGSysex::XGSysex ( unsigned short size )
 // Destructor
 XGSysex::~XGSysex (void)
 {
-	delete m_data;
+	delete [] m_data;
 }
 
 
