@@ -1,7 +1,7 @@
 // qxgeditCheck.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -102,6 +102,13 @@ XGParam *qxgeditCheck::param (void) const
 }
 
 
+// Value settler public slot.
+void qxgeditCheck::setValue ( unsigned short iValue )
+{
+	set_value(iValue, observer());
+}
+
+
 // Internal widget slots.
 void qxgeditCheck::checkToggled ( bool bCheck )
 {
