@@ -70,7 +70,7 @@ float qxgeditKnob::mouseAngle ( const QPoint& pos )
 // Alternate mouse behavior event handlers.
 void qxgeditKnob::mousePressEvent ( QMouseEvent *pMouseEvent )
 {
-	if (pMouseEvent->button() == Qt::MidButton) {
+	if (pMouseEvent->button() == Qt::MiddleButton) {
 		// Reset to default value...
 		if (m_iDefaultValue < minimum() || m_iDefaultValue > maximum())
 			m_iDefaultValue = (maximum() + minimum()) / 2;
@@ -133,7 +133,7 @@ void qxgeditKnob::mouseMoveEvent ( QMouseEvent *pMouseEvent )
 
 void qxgeditKnob::mouseReleaseEvent ( QMouseEvent *pMouseEvent )
 {
-	if (m_dialMode == DefaultMode && pMouseEvent->button() != Qt::MidButton) {
+	if (m_dialMode == DefaultMode && pMouseEvent->button() != Qt::MiddleButton) {
 		QDial::mouseReleaseEvent(pMouseEvent);
 	} else if (m_bMousePressed) {
 		m_bMousePressed = false;
