@@ -1,7 +1,7 @@
 // qxgeditOptions.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -234,12 +234,34 @@ bool qxgeditOptions::parse_args ( const QStringList& args )
 	parser.setApplicationDescription(
 		QXGEDIT_TITLE " - " + QObject::tr(QXGEDIT_SUBTITLE));
 
-	parser.addHelpOption();
-	parser.addVersionOption();
+	const QCommandLineOption& helpOption = parser.addHelpOption();
+	const QCommandLineOption& versionOption = parser.addVersionOption();
 	parser.addPositionalArgument("session-file",
 		QObject::tr("Session file (.syx)"),
 		QObject::tr("[session-file]"));
-	parser.process(args);
+
+	if (!parser.parse(args)) {
+		show_error(parser.errorText());
+		return false;
+	}
+
+	if (parser.isSet(helpOption)) {
+		show_error(parser.helpText());
+		return false;
+	}
+
+	if (parser.isSet(versionOption)) {
+		QString sVersion = QString("%1 %2\n")
+			.arg(QXGEDIT_TITLE)
+			.arg(QCoreApplication::applicationVersion());
+		sVersion += QString("Qt: %1").arg(qVersion());
+	#if defined(QT_STATIC)
+		sVersion += "-static";
+	#endif
+		sVersion += '\n';
+		show_error(sVersion);
+		return false;
+	}
 
 	foreach (const QString& sArg, parser.positionalArguments()) {
 		sessionFiles.append(QFileInfo(sArg).absoluteFilePath());
@@ -268,14 +290,14 @@ bool qxgeditOptions::parse_args ( const QStringList& args )
 			return false;
 		}
 		else if (sArg == "-v" || sArg == "--version") {
+			out << QString("%1: %2\n")
+				.arg(QXGEDIT_TITLE)
+				.arg(PROJECT_VERSION);
 			out << QString("Qt: %1").arg(qVersion());
 		#if defined(QT_STATIC)
 			out << "-static";
 		#endif
 			out << '\n';
-			out << QString("%1: %2\n")
-				.arg(QXGEDIT_TITLE)
-				.arg(PROJECT_VERSION);
 			return false;
 		} else {
 			// If we don't have one by now,
